import yaml
import json
import argparse

def create_property_schema(key, attributes):
    # Initialize the schema for this property
    prop_schema = {
        "type": attributes.get("mytype", "string"),
        "description": attributes.get("description", ""),
        "default": attributes.get("value", None),
    }

    # Handle empty string default explicitly
    if attributes.get("value") == "":
        prop_schema['default'] = ""

    # If there are nested properties directly under this key
    for sub_key, sub_attributes in attributes.items():
        #print(sub_key)
        #print(sub_attributes)
        if isinstance(sub_attributes, dict) and 'mytype' in sub_attributes:
            prop_schema["properties"] = prop_schema.get("properties", {})
            prop_schema["properties"][sub_key] = create_property_schema(sub_key, sub_attributes)
  
    return prop_schema

def convert_to_schema(data):
    key = list(data.keys())[0]  # Get the very first key
    attributes = data[key]
    
    schema = {
        "type": "object",
        "properties": {
            key: create_property_schema(key, attributes)
        },
        "required": []
    }

    # Check if the first key is required
    if attributes.get("required", False):
        schema["required"].append(key)

    return schema

def main(values_file, schema_file):
    # Read the input YAML file
    with open(values_file, 'r') as f:
        values = yaml.safe_load(f)

    # Check for non-empty values
    if not values or len(values) == 0:
        raise ValueError("YAML file is empty or not structured correctly.")

    # Convert the loaded data to JSON schema
    schema = convert_to_schema(values)

    # Write the resulting JSON schema to the output file
    with open(schema_file, 'w') as f:
        json.dump(schema, f, indent=2)

    print(f"Schema generated and saved to {schema_file}")

if __name__ == "__main__":
    # Set up command line argument parsing
    parser = argparse.ArgumentParser(description='Convert values.yaml to schema.json.')
    parser.add_argument('values_file', help='Path to the input values.yaml file')
    parser.add_argument('schema_file', help='Path to the output schema.json file')

    # Parse the arguments
    args = parser.parse_args()

    # Call the main function with the provided arguments
    main(args.values_file, args.schema_file)
