import yaml
import argparse

def extract_data(data, parent_key=''):
    rows = []
    for key, attributes in data.items():
        full_key = f"{parent_key}.{key}" if parent_key else key
        if isinstance(attributes, dict):
            if attributes.get('mytype') == 'object' and attributes.get('value') != {}:
                # Extract nested keys
                nested_rows = extract_data(attributes, full_key)
                rows.extend(nested_rows)
            else:
                # Handle non-object attributes and check for value not being empty
                value = attributes.get('value')
                #if value:  # Only include if there is a non-empty value
                description = attributes.get('description', '').strip()
                type_ = attributes.get('mytype', '')
                required = attributes.get('required', False)
                default = attributes.get('value', '')
                rows.append((full_key, description, type_, str(required).lower(), str(default)))
        else:
            # If the attributes are not a dict (should not happen in this case)
            continue
    return rows

def create_markdown_table(data):
    if not data:
        return "No valid parameters found."

    header = "| Key | Description | Type | Required | Default |\n|---|---|---|---|---|\n"
    rows = "\n".join(f"| `{key}` | {description} | {type_} | {required} | {default} |" for key, description, type_, required, default in data)
    return header + rows

def main(values_file, markdown_file):
    with open(values_file, 'r') as f:
        values = yaml.safe_load(f)

    #extracted_data = extract_data(values['gwcelery'])
    extracted_data = extract_data(values)

    markdown_table = create_markdown_table(extracted_data)

    with open(markdown_file, 'w') as f:
        f.write(markdown_table)

    print(f"Markdown table generated and saved to {markdown_file}")

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='Convert values.yaml to Markdown table.')
    parser.add_argument('values_file', help='Path to the input values.yaml file')
    parser.add_argument('markdown_file', help='Path to the output markdown file')

    args = parser.parse_args()

    main(args.values_file, args.markdown_file)
